aboutsummaryrefslogtreecommitdiff
path: root/azalea-world/src/container.rs
diff options
context:
space:
mode:
authormat <github@matdoes.dev>2023-03-11 17:02:57 -0600
committermat <github@matdoes.dev>2023-03-11 17:02:57 -0600
commitcd0a1ed8d4c7670eb58d33f521026e760798e1a5 (patch)
tree5b47c3ab6ffa3cd2b87b26a24bfb854a53885fc4 /azalea-world/src/container.rs
parent40a0c8acfbfb88be791c295a14014468e2fd4298 (diff)
downloadazalea-drasl-cd0a1ed8d4c7670eb58d33f521026e760798e1a5.tar.xz
fix doc errors
Diffstat (limited to 'azalea-world/src/container.rs')
-rw-r--r--azalea-world/src/container.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/azalea-world/src/container.rs b/azalea-world/src/container.rs
index fdd89a75..c8af8c99 100644
--- a/azalea-world/src/container.rs
+++ b/azalea-world/src/container.rs
@@ -10,10 +10,10 @@ use std::{
use crate::{ChunkStorage, Instance};
/// A container of [`World`]s. Worlds are stored as a Weak pointer here, so
/// if no clients are using a world it will be forgotten.
#[derive(Default, Resource)]
-pub struct WorldContainer {
+pub struct InstanceContainer {
// We just refer to the chunks here and don't include entities because there's not that many
// cases where we'd want to get every entity in the world (just getting the entities in chunks
// should work fine).
@@ -29,9 +29,9 @@ pub struct WorldContainer {
pub worlds: HashMap<ResourceLocation, Weak<RwLock<Instance>>>,
}
-impl WorldContainer {
+impl InstanceContainer {
pub fn new() -> Self {
- WorldContainer {
+ InstanceContainer {
worlds: HashMap::new(),
}
}
@@ -10,10 +10,10 @@ use std::{
use crate::{ChunkStorage, Instance};
-/// A container of [`World`]s. Worlds are stored as a Weak pointer here, so
-/// if no clients are using a world it will be forgotten.
+/// A container of [`Instance`]s (aka worlds). Instances are stored as a Weak
+/// pointer here, so if no clients are using an instance it will be forgotten.
#[derive(Default, Resource)]